# pylint: disable=line-too-long
# Source from: https://github.com/Azure/azure-workload-identity/blob/main/examples/msal-python/token_credential.py

import os
from .token_credential import ClientAssertionCredential

# pylint: disable=consider-using-f-string


def get_token_credential():
    # get environment variables to authenticate to the key vault
    azure_client_id = os.getenv('AZURE_CLIENT_ID', '')
    azure_tenant_id = os.getenv('AZURE_TENANT_ID', '')
    azure_authority_host = os.getenv('AZURE_AUTHORITY_HOST', '')
    azure_federated_token_file = os.getenv('AZURE_FEDERATED_TOKEN_FILE', '')

    # create a token credential object, which has a get_token method that returns a token
    token_credential = ClientAssertionCredential(
        azure_client_id, azure_tenant_id, azure_authority_host, azure_federated_token_file)

    return token_credential



# pylint: disable=line-too-long
# Source from: https://github.com/Azure/azure-workload-identity/blob/main/examples/msal-python/token_credential.py

import time

from azure.core.credentials import AccessToken
from msal import ConfidentialClientApplication

# The following code demonstrates the use of the msal library to
# authenticate with a service using client assertion.

# pylint: disable=too-few-public-methods


class ClientAssertionCredential:

    def __init__(self, azure_client_id, azure_tenant_id, azure_authority_host,
                 azure_federated_token_file):
        # read the projected service account token file
        f = open(azure_federated_token_file, 'rb')
        # create a confidential client application
        self.app = ConfidentialClientApplication(
            azure_client_id,
            client_credential={
                'client_assertion': f.read().decode("utf-8")
            },
            # pylint: disable=consider-using-f-string
            authority="{}{}".format(azure_authority_host, azure_tenant_id)
        )

    # pylint: disable=unused-argument
    def get_token(self, *scopes, **kwargs):
        # get the token using the application
        token = self.app.acquire_token_for_client(scopes)
        if 'error' in token:
            raise Exception(token['error_description'])
        expires_on = time.time() + token['expires_in']
        # return an access token with the token string and expiration time
        return AccessToken(token['access_token'], int(expires_on))



import os
from pymongo import MongoClient
from . import keyvault
from . import utils


def get_collection(database: str, collection: str):
    use_keyvault = utils.to_bool(os.environ['USE_KEYVAULT'])
    if use_keyvault is True:
        connection_string = keyvault.get_cosmos_connection_string()
    else:
        connection_string = os.environ['COSMOSDB_CONNECTION_STRING']
    return MongoClient(connection_string).get_database(database).get_collection(collection)



import os

from azure.identity import DefaultAzureCredential
from azure.keyvault.secrets import SecretClient
from . import utils
from . import msal


def get_cosmos_connection_string():
    return _get_secret("cosmosdb-connection-string")


def _get_secret(secret: str):
    url = os.environ['KEYVAULT_URL']
    use_token_credential = utils.to_bool(os.environ['USE_TOKEN_CREDENTIAL'])
    if use_token_credential is True:
        credential = msal.get_token_credential()
    else:
        credential = DefaultAzureCredential()
    secret_client = SecretClient(vault_url=url, credential=credential)
    return secret_client.get_secret(secret).value



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['src']

package_data = \
{'': ['*']}

install_requires = \
['azure-identity>=1.10.0,<2.0.0',
 'azure-keyvault-secrets>=4.4.0,<5.0.0',
 'pymongo>=4.1.1,<5.0.0']

setup_kwargs = {
    'name': 'epomatti-aksmrc-core',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'Evandro Pomatti',
    'author_email': 'evandro.pomatti@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
